/******************** (C) COPYRIGHT 2004 STMicroelectronics **************************
* File Name          : main.c													     *
* Description        : Toggling  port 2 pins' state                                  * 
*                                                                                    *
*                                                                                    *
* Purpose:  one LED after another when pressing the push button                      *
*          Use a simple delay to suppress key bouncing.                              *
*                                                                                    *
*                                                                                    *
* OUTPUTS:                                                                           *
* Port 2.0                               driving LED #1                              *
* Port 2.1                               driving LED #2                              *
* Port 2.2                               driving LED #3                              *
* Port 2.3                               driving LED #4                              *
* Port 2.4                               Connected to a Push Button                  *                                                     
**************************************************************************************
*/
/*************************************************************************************
* INCLUDES
*************************************************************************************/
#include <reg276.h>

sfrbit DP20 _atbit(DP2,0);                                    /* Output, LED #1   */
sfrbit DP21 _atbit(DP2,1);                                    /* Output, LED #2   */
sfrbit DP22 _atbit(DP2,2);                                    /* Output, LED #3   */
sfrbit DP23 _atbit(DP2,3);                                    /* Output, LED #4   */
sfrbit DP24 _atbit(DP2,4);                                 /* Input,  Push Button */
void delay( void );
/*
**************************************main********************************************
*/
main()
{
  volatile unsigned int port;
  volatile unsigned char counter;
 
  DP20 = DP21 = DP22 = DP23 = 0x01;	        /* Port 2  pins configured in output */
  DP24 = 0x00;                                      /* Push button = input       */
  
  counter = 0;                                                /* Clear counter   */
  P2 = 0xFF;                                                         /* LEDs off */
	  
  while(1)       
  {	      
    port = P2;								      /* Read the switch from port 2 */           
    port &= 0x0010;							/* Isolate the switch value Pin P2.4 */
    if (port)			                                    /*Push button pressed*/
	  {
									  
			switch (counter)
			{

				case 0: P2 = 0xFE; 		                 	/* Switch ON LED #1 */
					counter++;
					break;

				case 1: P2 = 0xFD; 		               	    /* Switch ON LED #2 */
					counter++;
					break;

				case 2: P2 = 0xFB; 		                	/* Switch ON LED #3 */
					counter++;
					break;

				case 3: P2 = 0xF7; 		     	            /* Switch ON LED #4 */
					counter++;
					break;
															
				case 4: P2 = 0xFF; 			         /* Switch OFF the four LEDs*/
					counter = 0;			               /* Reset the counter */

			  	break;

			}                                                    /* End Switch */

	  }                                                              /* End If */
	  delay();			                /* Do some delay to avoid key bouncing */
	}                                                             /* End while */

}                                                                  /* End main */






/*
**************************************************************************************
Routine: delay
Input : None
Return: None 
Purpose: Gives a delay  
**************************************************************************************
*/   

        
void delay( void )
{
	volatile unsigned int t1, t2, t3=0;
       	
  for( t1 = 10000; t1 > 0; t1-- )  {
  	for( t2 = 0xffff; t2 > 0; t2++ )
     	t3++;
     }
}



/******************* (C) COPYRIGHT 2004 STMicroelectronics *****END OF FILE**********/ 
